@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::GenericInterface::Mapping;
@@ -49,6 +49,10 @@ create an object.
     );
     my $MappingObject = Kernel::GenericInterface::Mapping->new(
         DebuggerObject => $DebuggerObject,
+        Invoker        => 'TicketLock',            # the name of the invoker in the web service
+        InvokerType    => 'Nagios::TicketLock',    # the Invoker backend to use
+        Operation      => 'TicketCreate',          # the name of the operation in the web service
+        OperationType  => 'Ticket::TicketCreate',  # the local operation backend to use
         MappingConfig => {
             Type => 'MappingSimple',
             Config => {
@@ -79,6 +83,14 @@ sub new {
         $Self->{$Needed} = $Param{$Needed};
     }
 
+    # add optional params
+    OPTIONAL:
+    for my $Optional (qw(Invoker InvokerType Operation OperationType)) {
+        next OPTIONAL if !$Param{$Optional};
+
+        $Self->{$Optional} = $Param{$Optional};
+    }
+
     # check config - we need at least a config type
     if ( !IsHashRefWithData( $Param{MappingConfig} ) ) {
 
@@ -169,10 +181,10 @@ sub Map {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
